*******************
rchive
*******************

overview
=============

rchive is Dorado's tooling for file/data handling. rchive can make a data directory to work in, obtain the date for location of data folders, search and catalogue data folders, read in data series, write data series, and construct file strings for other functions.

rchive's goal is to create a consistent file IO pattern for Dorado and its derivatives to work off of; while keeping data organized and safe.

rchive will soon allow for more robust saving of data series.

Reference/API
=============

.. automodapi:: dorado.rchive